developerscripttools.SvnMessageScript
=====================================

.. inheritance-diagram:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.alias

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.commit_message_path

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.scripting_group

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.process_args

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
